@@ -59,8 +59,8 @@ class Context:
                  polygon_cls: _Type[_hints.Polygon] = _geometries.Polygon,
                  segment_cls: _Type[_hints.Segment] = _geometries.Segment,
                  mode: Mode = Mode.EXACT,
-                 sqrt: _Callable[[_hints.Scalar], _hints.Scalar]
-                 = _sqrt) -> None:
+                 sqrt: _Callable[[_hints.Scalar], _hints.Scalar] = _sqrt
+                 ) -> None:
         self._box_cls = box_cls
         self._contour_cls = contour_cls
         self._empty, self._empty_cls = empty_cls(), empty_cls
@@ -354,8 +354,7 @@ class Context:
 
     def box_segment_squared_distance(self,
                                      box: _hints.Box,
-                                     segment: _hints.Segment
-                                     ) -> _hints.Scalar:
+                                     segment: _hints.Segment) -> _hints.Scalar:
         """
         Returns squared Euclidean distance between box and a segment.
 
@@ -422,10 +421,10 @@ class Context:
         return self._centroidal.contour_centroid(contour, self.point_cls,
                                                  self.sqrt)
 
-    def contour_edges(self, contour: _hints.Contour
-                      ) -> _Sequence[_hints.Segment]:
+    def contour_segments(self, contour: _hints.Contour
+                         ) -> _Sequence[_hints.Segment]:
         """
-        Constructs edges of a contour.
+        Constructs segments of a contour.
 
         Time complexity:
             ``O(len(contour.vertices))``
@@ -436,8 +435,8 @@ class Context:
         >>> Contour = context.contour_cls
         >>> Point = context.point_cls
         >>> Segment = context.segment_cls
-        >>> (context.contour_edges(Contour([Point(0, 0), Point(2, 0),
-        ...                                 Point(2, 2), Point(0, 2)]))
+        >>> (context.contour_segments(Contour([Point(0, 0), Point(2, 0),
+        ...                                    Point(2, 2), Point(0, 2)]))
         ...  == [Segment(Point(0, 2), Point(0, 0)),
         ...      Segment(Point(0, 0), Point(2, 0)),
         ...      Segment(Point(2, 0), Point(2, 2)),
@@ -807,8 +806,7 @@ class Context:
 
     def segment_point_squared_distance(self,
                                        segment: _hints.Segment,
-                                       point: _hints.Point
-                                       ) -> _hints.Scalar:
+                                       point: _hints.Point) -> _hints.Scalar:
         """
         Returns squared Euclidean distance between segment and a point.
 
