@@ -1,9 +1,9 @@
 from fractions import Fraction
 
-from .hints import Coordinate
+from .hints import Scalar
 
 
-def robust_divide(dividend: Coordinate, divisor: Coordinate) -> Coordinate:
+def robust_divide(dividend: Scalar, divisor: Scalar) -> Scalar:
     return (dividend / Fraction(divisor)
             if isinstance(divisor, int)
             else dividend / divisor)
