@@ -1,25 +1,25 @@
 from fractions import Fraction
-from typing import (Callable,
-                    Sequence,
+from typing import (Sequence,
                     Tuple,
                     Type)
 
-from ground.core.hints import (Coordinate,
-                               Point)
+from ground.core.hints import (Contour,
+                               Point,
+                               Scalar)
 
 
-def centroid(vertices: Sequence[Point],
+def centroid(contour: Contour,
              point_cls: Type[Point],
-             inverse: Callable[[int], Fraction] = Fraction(1).__truediv__
-             ) -> Point:
-    x_numerator, y_numerator, double_area = centroid_components(vertices)
-    inverted_divisor = inverse(3 * double_area)
+             third: Fraction = Fraction(1, 3)) -> Point:
+    x_numerator, y_numerator, double_area = centroid_components(
+            contour.vertices)
+    inverted_divisor = third / double_area
     return point_cls(x_numerator * inverted_divisor,
                      y_numerator * inverted_divisor)
 
 
 def centroid_components(vertices: Sequence[Point]
-                        ) -> Tuple[Coordinate, Coordinate, Coordinate]:
+                        ) -> Tuple[Scalar, Scalar, Scalar]:
     double_area = x_numerator = y_numerator = 0
     prev_vertex = vertices[-1]
     prev_x, prev_y = prev_vertex.x, prev_vertex.y
