@@ -1,15 +1,15 @@
 from fractions import Fraction
-from typing import Sequence
 
-from ground.core.hints import (Coordinate,
-                               Point)
+from ground.core.hints import (Contour,
+                               Scalar)
 from ground.core.shewchuk import (sum_expansions,
                                   to_cross_product)
 
 
-def signed_area(vertices: Sequence[Point],
+def signed_area(contour: Contour[Scalar],
                 *,
-                _half: Fraction = Fraction(1, 2)) -> Coordinate:
+                _half: Fraction = Fraction(1, 2)) -> Scalar:
+    vertices = contour.vertices
     result, vertex = (0,), vertices[-1]
     for next_vertex in vertices:
         result = sum_expansions(result,
